@@ -21,10 +21,10 @@ elastic_vars = {
     "__ip__" : "45.56.113.162",
     "__port__": 9200,
     "__user__": "elastic",
-    "__password": "uZCxWGE35lD3lhc",
+    "__password__": "uZCxWGE35lD3lhc",
     "__es__": Elasticsearch(
-        "45.56.113.162",
-        port=9200,
+        host="45.56.113.162:9200",
+        
         user= "elastic",
         password="uZCxWGE35lD3lhc"
         )
@@ -47,13 +47,10 @@ def set_elastic_vars(__ip__=None, __port__=None, __user__= None, __password__= N
             elastic_vars[a]=b
             has_changed=True
     if has_changed:
-        elastic_vars["__es__"] = Elasticsearch(
-            elastic_vars["__ip__"],
-            port=elastic_vars["__port__"],
-            user=elastic_vars["__user__"],
-            password=elastic_vars["__password__"]
-            
-        )
+        host= elastic_vars["__ip__"]+":"+str(elastic_vars["__port__"])
+        elastic_vars["__es__"] = Elasticsearch([host],
+                                               http_auth=(elastic_vars["__user__"],
+                                                          elastic_vars["__password"]))
     return 1
 
 def login(__username__="", __password__="", __host__="45.56.109.120", __port__=14096, __database__="Sun"):
